<?php
/**
 * Customizer active callbacks
 *
 * @package Theme Palace
 * @subpackage  Whole
 * @since  Whole 1.0.0
 */


if ( ! function_exists( 'whole_is_static_homepage_enable' ) ) :
	/**
	 * Check if static homepage is enabled.
	 *
	 * @since Whole 1.0.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function whole_is_static_homepage_enable( $control ) {
		return ( 'page' == $control->manager->get_setting( 'show_on_front' )->value() );
	}
endif;

if ( ! function_exists( 'whole_is_breadcrumb_enable' ) ) :
	/**
	 * Check if breadcrumb is enabled.
	 *
	 * @since  Whole 1.0.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function whole_is_breadcrumb_enable( $control ) {
		return $control->manager->get_setting( 'whole_theme_options[breadcrumb_enable]' )->value();
	}
endif;

if ( ! function_exists( 'whole_is_pagination_enable' ) ) :
	/**
	 * Check if pagination is enabled.
	 *
	 * @since  Whole 1.0.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function whole_is_pagination_enable( $control ) {
		return $control->manager->get_setting( 'whole_theme_options[pagination_enable]' )->value();
	}
endif;

/**
 * Check if hero slider section is enabled.
 *
 * @since  Whole 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function whole_is_hero_banner_section_enable( $control ) {
	return ( $control->manager->get_setting( 'whole_theme_options[hero_banner_section_enable]' )->value() );
}

function whole_is_hero_banner_bg_color_section_enable( $control ) {
	return ( true === ( $control->manager->get_setting( 'whole_theme_options[hero_banner_bg_color_enable]' )->value() ) );
}

/**
 * Check if hero slider section content type is post.
 *
 * @since  Whole 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function whole_is_hero_banner_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'whole_theme_options[hero_banner_content_type]' )->value();
	return whole_is_hero_banner_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if hero slider section content type is page.
 *
 * @since  Whole 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function whole_is_hero_banner_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'whole_theme_options[hero_banner_content_type]' )->value();
	return whole_is_hero_banner_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if hero slider section content type is category.
 *
 * @since  Whole 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function whole_is_hero_banner_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'whole_theme_options[hero_banner_content_type]' )->value();
	return whole_is_hero_banner_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if hero slider section content type is trip.
 *
 * @since  Whole 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function whole_is_hero_banner_section_content_trip_enable( $control ) {
	$content_type = $control->manager->get_setting( 'whole_theme_options[hero_banner_content_type]' )->value();
	return whole_is_hero_banner_section_enable( $control ) && ( 'trip' == $content_type );
}

/**
 * Check if welcome section is enabled.
 *
 * @since Whole 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function whole_is_welcome_section_enable( $control ) {
	return ( $control->manager->get_setting( 'whole_theme_options[welcome_section_enable]' )->value() );
}

/**
 * Check if welcome section content type is post.
 *
 * @since Whole 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function whole_is_welcome_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'whole_theme_options[welcome_content_type]' )->value();
	return whole_is_welcome_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if welcome section content type is page.
 *
 * @since Whole 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function whole_is_welcome_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'whole_theme_options[welcome_content_type]' )->value();
	return whole_is_welcome_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if welcome section content type is custom.
 *
 * @since Whole 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function whole_is_welcome_section_content_custom_enable( $control ) {
	$content_type = $control->manager->get_setting( 'whole_theme_options[welcome_content_type]' )->value();
	return whole_is_welcome_section_enable( $control ) && ( 'custom' == $content_type );
}
/**
 * Check if contact section is enabled.
 *
 * @since  Whole 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function whole_is_contact_section_enable( $control ) {
	return ( $control->manager->get_setting( 'whole_theme_options[contact_section_enable]' )->value() );
}



/**
 * Check if call_to_action section is enabled.
 *
 * @since Whole 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function whole_is_call_to_action_section_enable( $control ) {
	return ( $control->manager->get_setting( 'whole_theme_options[call_to_action_section_enable]' )->value() );
}

/**
 * Check if call_to_action section content type is page.
 *
 * @since Whole 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function whole_is_call_to_action_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'whole_theme_options[call_to_action_content_type]' )->value();
	return whole_is_call_to_action_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if call_to_action section content type is post.
 *
 * @since Whole 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function whole_is_call_to_action_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'whole_theme_options[call_to_action_content_type]' )->value();
	return whole_is_call_to_action_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if call_to_action section content type is custom.
 *
 * @since Whole 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function whole_is_call_to_action_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'whole_theme_options[call_to_action_content_type]' )->value();
	return whole_is_call_to_action_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if call_to_action section content type is custom.
 *
 * @since Whole 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function whole_is_call_to_action_section_content_custom_enable( $control ) {
	$content_type = $control->manager->get_setting( 'whole_theme_options[call_to_action_content_type]' )->value();
	return whole_is_call_to_action_section_enable( $control ) && ( 'custom' == $content_type );
}

/**
 * Check if call_to_action separator section is enabled.
 *
 * @since  Whole 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function whole_is_call_to_action_section_separator_enable( $control ) {
    $content_type = $control->manager->get_setting( 'whole_theme_options[call_to_action_content_type]' )->value();
    return whole_is_call_to_action_section_enable( $control ) && !( 'recent' == $content_type || 'category' == $content_type ) ;
}


/**
 * Check if projects section is enabled.
 *
 * @since Whole 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function whole_is_projects_section_enable( $control ) {
	return ( $control->manager->get_setting( 'whole_theme_options[projects_section_enable]' )->value() );
}

/**
 * Check if projects section content type is page.
 *
 * @since Whole 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function whole_is_projects_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'whole_theme_options[projects_content_type]' )->value();
	return whole_is_projects_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if projects section content type is post.
 *
 * @since Whole 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function whole_is_projects_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'whole_theme_options[projects_content_type]' )->value();
	return whole_is_projects_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if projects section content type is custom.
 *
 * @since Whole 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function whole_is_projects_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'whole_theme_options[projects_content_type]' )->value();
	return whole_is_projects_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if projects section content type is custom.
 *
 * @since Whole 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function whole_is_projects_section_content_custom_enable( $control ) {
	$content_type = $control->manager->get_setting( 'whole_theme_options[projects_content_type]' )->value();
	return whole_is_projects_section_enable( $control ) && ( 'custom' == $content_type );
}

/**
 * Check if projects separator section is enabled.
 *
 * @since  Whole 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function whole_is_projects_section_separator_enable( $control ) {
    $content_type = $control->manager->get_setting( 'whole_theme_options[projects_content_type]' )->value();
    return whole_is_projects_section_enable( $control ) && !( 'recent' == $content_type || 'category' == $content_type ) ;
}
