<?php
/**
 * Customizer default options
 *
 * @package Theme Palace
 * @subpackage  Whole
 * @since  Whole 1.0.0
 * @return array An array of default values
 */

function whole_get_default_theme_options() {
	$theme_data = wp_get_theme();
	$whole_default_options = array(

		// Color Options
		'header_title_color'			    => '#000',
		'header_tagline_color'			    => '#000',
		'header_txt_logo_extra'			    => 'show-all',

		// breadcrumb
		'breadcrumb_enable'				    => (bool) true,
		'breadcrumb_separator'			    => '/',
				
		// homepage options
		'enable_frontpage_content' 			=> false,

		// layout 
		'site_layout'         			    => 'wide',
		'sidebar_position'         		    => 'right-sidebar',
		'post_sidebar_position' 		    => 'right-sidebar',
		'page_sidebar_position' 		    => 'right-sidebar',

		//menu
		'social_menu'					    => (bool) true,
		'top_bar_phoneNumber'	    		=> '',
		'top_bar_address'					=> '',
		'top_bar_email'			    		=> '',

		// excerpt options
		'long_excerpt_length'               => 25,

		// pagination options
		'pagination_enable'         	    => (bool) true,
		'pagination_type'         		    => 'default',

		// footer options
		'copyright_text'           		    => esc_html__( 'Copyright © 2022 ', 'whole' ) . esc_html( $theme_data->get( 'Name') ) . '&nbsp;' . esc_html__( 'by', 'whole' ). '&nbsp;<a target="_blank" href="'. esc_url( $theme_data->get( 'AuthorURI' ) ) .'">'. esc_html( ucwords( $theme_data->get( 'Author' ) ) ) .'</a>',
		'scroll_top_visible'        	    => (bool) true,

		// reset options
		'reset_options'      			    => (bool) false,
		
		'default_sortable' 			    	=> 'hero_banner,welcome,projects,call_to_action,contact',

		// blog/archive options
		'your_latest_posts_title' 		    => esc_html__( 'Blogs', 'whole' ),
		'archive_btn_txt' 		    		=> esc_html__( 'Read More', 'whole' ),
		'blog_column'						=> 'col-2',

		// single post theme options
		'single_post_hide_date' 		    => (bool) false,
		'single_post_hide_author'		    => (bool) false,
		'single_post_hide_category'		    => (bool) false,
		'single_post_hide_tags'			    => (bool) false,
		'single_post_hide_pagination'		=> (bool) false,
		'hide_category'			   			=> (bool) false,
		'hide_date'			   				=> (bool) false,

		/* Front Page */

		// Welcome
		'welcome_section_enable'			=> false,
		'welcome_excerpt_length'			=> 40,
		'welcome_content_type'			    => 'page',
		'welcome_content_title'				=> esc_html__( 'The real-time & powerful theme', 'whole' ),
		'welcome_title'						=> esc_html__( 'Welcome', 'whole' ),
		'welcome_btn_title'					=> esc_html__( 'Learn More', 'whole' ),
		'welcome_content_description'		=> esc_html__( 'Start-ups you might dive directly into the work. In less than a few hours you get the source files, a shared drive link, a few simple tasks and there you go — you will learn while working. Be ready to wait even for two or three weeks until you get to test, perform a study or move pixels. It is a long established fact that a reader will be distracted by the readable content of a page when looking at its layout.', 'whole' ),

		// contact
		'contact_section_enable'			=> (bool) false,
		'contact_section_title'			    => esc_html__( 'Contact Us', 'whole' ),
		'contact_content_title'			    => esc_html__( 'Hello World', 'whole' ),
		'contact_content_description'       => esc_html__( 'Start-ups you might dive directly into the work. In less than a few hours you get the source files, a shared drive link.', 'whole' ),
		'contact_contact_title'         	=> esc_html__('Hello World','whole'),
		'contact_contact_description'       => esc_html__( 'Start-ups you might dive directly into the work. In less than a few hours you get the source files, a shared drive link.', 'whole' ),

		// hero slider
		'hero_banner_section_enable'			=> (bool) false,
		'hero_banner_autoplay_enable'			=> (bool) false,
		'hero_banner_content_type'				=> 'post',
		'hero_banner_count'				 		=> 3,
		'hero_banner_btn_txt'            	    => esc_html__('Launch App','whole'),
		'hero_banner_alt_btn_txt'               => esc_html__('Learn More','whole'),

		//call_to_action
		'call_to_action_section_enable'				=> (bool) false,
		'call_to_action_content_type'			    => 'post',
		'call_to_action_title'						=> esc_html__('Call To Action','whole'),
		'call_to_action_content_title'				=> esc_html__('Design for  people','whole'),
		'call_to_action_content_subtitle'			=> esc_html__('The real-time & powerful theme','whole'),
		'call_to_action_description'				=> __('Give your audience what they want — more episodes of your podcast. There\'s nothing more frustating than finding a podcast you love, only to run out of episodes to binge.','whole'),
		'call_to_action_excerpt_length'				=> 40,
	
		//projects
		'projects_section_enable'				=> (bool) false,
		'projects_content_type'			  		=> 'post',
		'projects_title'						=> esc_html__('Projects','whole'),
		'projects_excerpt_length'				=> 40,
		'projects_count'						=> 3,
		'projects_btn_txt'                  	=> esc_html__('Learn More','whole'),

	);

	$output = apply_filters( 'whole_default_theme_options', $whole_default_options );

	// Sort array in ascending order, according to the key:
	if ( ! empty( $output ) ) {
		ksort( $output );
	}

	return $output;
}