<?php
/**
 * Call To Action Section options
 *
 * @package Theme Palace
 * @subpackage Whole
 * @since Whole 1.0.0
 */

// Add Call To Action section
$wp_customize->add_section( 'whole_call_to_action_section',
	array(
		'title'             => esc_html__( 'Call To Action','whole' ),
		'description'       => esc_html__( 'Call To Action  Section options.', 'whole' ),
        'panel'             => 'whole_front_page_panel',
	)
);

// Call To Action content enable control and setting
$wp_customize->add_setting( 'whole_theme_options[call_to_action_section_enable]',
	array(
		'default'			=> 	$options['call_to_action_section_enable'],
		'sanitize_callback' => 'whole_sanitize_switch_control',
	)
);

$wp_customize->add_control( new Whole_Switch_Control( $wp_customize,
	'whole_theme_options[call_to_action_section_enable]',
		array(
			'label'             => esc_html__( 'Call To Action Section Enable', 'whole' ),
			'section'           => 'whole_call_to_action_section',
			'on_off_label' 		=> whole_switch_options(),
		)
	)
);

// our_service title setting and control
$wp_customize->add_setting( 'whole_theme_options[call_to_action_title]',
    array(
        'sanitize_callback' => 'sanitize_text_field',
        'default'           => $options['call_to_action_title'],
        'transport'         => 'postMessage',
    )
);

$wp_customize->add_control( 'whole_theme_options[call_to_action_title]',
    array(
        'label'             => esc_html__( 'Section Title', 'whole' ),
        'section'           => 'whole_call_to_action_section',
        'active_callback'   => 'whole_is_call_to_action_section_enable',
        'type'              => 'text',
    )
);

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'whole_theme_options[call_to_action_title]',
        array(
            'selector'            => '#whole_call_to_action h2.section-title',
            'settings'            => 'whole_theme_options[call_to_action_title]',
            'container_inclusive' => false,
            'fallback_refresh'    => true,
            'render_callback'     => 'whole_call_to_action_title_partial',
        )
    );
}

// about image setting and control.
$wp_customize->add_setting( 'whole_theme_options[call_to_action_bg_image]',
	array(
		'sanitize_callback' => 'whole_sanitize_image'
	)
);

$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize,
	'whole_theme_options[call_to_action_bg_image]',
		array(
			'label'       		=> esc_html__( 'Background Image', 'whole' ),
			'description' 		=> sprintf( esc_html__( 'Recommended size: %1$dpx x %2$dpx ', 'whole' ), 512, 520 ),
			'section'     		=> 'whole_call_to_action_section',
			'active_callback'	=> 'whole_is_call_to_action_section_enable',
		)
	)
);


// long Excerpt length setting and control.
$wp_customize->add_setting( 'whole_theme_options[call_to_action_excerpt_length]',
	array(
		'sanitize_callback' => 'whole_sanitize_number_range',
		'validate_callback' => 'whole_validate_long_excerpt',
		'default'			=> $options['call_to_action_excerpt_length'],
	)
);

$wp_customize->add_control( 'whole_theme_options[call_to_action_excerpt_length]',
	array(
		'label'       		=> esc_html__( 'Excerpt Length', 'whole' ),
		'description' 		=> esc_html__( 'Total description words to be displayed in about posts.', 'whole' ),
		'section'     		=> 'whole_call_to_action_section',
		'active_callback' 	=> 'whole_is_call_to_action_section_enable',
		'type'        		=> 'number',
		'input_attrs' 		=> array(
			'style'       => 'width: 80px;',
			'max'         => 100,
			'min'         => 1,
		),
	)
);

// slider pages drop down chooser control and setting
$wp_customize->add_setting( 'whole_theme_options[call_to_action_content_page]', 
	array(
		'sanitize_callback' => 'whole_sanitize_page',
	)
);

$wp_customize->add_control( new  Whole_Dropdown_Chooser( $wp_customize,
	'whole_theme_options[call_to_action_content_page]', 
		array(
			'label'             => esc_html__( 'Select Page', 'whole'),
			'section'           => 'whole_call_to_action_section',
			'choices'			=> whole_page_choices(),
			'active_callback'	=> 'whole_is_call_to_action_section_enable',
		)
	)
);

// call_to_action title setting and control
$wp_customize->add_setting( 'whole_theme_options[call_to_action_content_subtitle]',
    array(
        'sanitize_callback' => 'sanitize_text_field',
        'default'           => $options['call_to_action_content_subtitle'],
        'transport'         => 'postMessage',
    )
);

$wp_customize->add_control( 'whole_theme_options[call_to_action_content_subtitle]',
    array(
        'label'             => esc_html__( 'Content Sub Title', 'whole' ),
        'section'           => 'whole_call_to_action_section',
        'type'              => 'text',
		'active_callback'	=> 'whole_is_call_to_action_section_enable',
    )
);

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'whole_theme_options[call_to_action_content_subtitle]',
        array(
            'selector'            => '#whole_call_to_action .entry-header .entry-title',
            'settings'            => 'whole_theme_options[call_to_action_content_subtitle]',
            'container_inclusive' => false,
            'fallback_refresh'    => true,
            'render_callback'     => 'whole_call_to_action_content_subtitle_partial',
        )
    );
}


// Add dropdown categories setting and control.
$wp_customize->add_setting( 'whole_theme_options[call_to_action_content_multitple_page]',
    array(
        'sanitize_callback' => 'whole_sanitize_page_list',
    )
);

$wp_customize->add_control( new Whole_Dropdown_Multiple_Chooser( $wp_customize,
    'whole_theme_options[call_to_action_content_multitple_page]',
        array(
            'label'             => esc_html__( 'Select Multiple Page', 'whole' ),
            'section'           => 'whole_call_to_action_section',
            'type'              => 'dropdown_multiple_chooser',
            'choices'           =>  whole_page_choices(),
            'active_callback'   => 'whole_is_call_to_action_section_enable'
        )
    )
);