<?php
/**
 * Contact Section options
 *
 * @package Theme Palace
 * @subpackage  Whole
 * @since  Whole 1.0.0
 */

// Add Contact section
$wp_customize->add_section( 'whole_contact_section', 
    array(
        'title'             => esc_html__( 'Contact','whole' ),
        'description'       => esc_html__( 'Contact  Section options.', 'whole' ),
        'panel'             => 'whole_front_page_panel',
    ) 
);

// Contact content enable control and setting
$wp_customize->add_setting( 'whole_theme_options[contact_section_enable]', 
    array(
        'default'			=> 	$options['contact_section_enable'],
        'sanitize_callback' => 'whole_sanitize_switch_control',
    ) 
);

$wp_customize->add_control( new  Whole_Switch_Control( $wp_customize,
    'whole_theme_options[contact_section_enable]',
        array(
            'label'             => esc_html__( 'Contact Section Enable', 'whole' ),
            'section'           => 'whole_contact_section',
            'on_off_label' 		=> whole_switch_options(),
        ) 
    )
);

// contact section title control and setting
$wp_customize->add_setting( 'whole_theme_options[contact_section_title]',
    array(
        'sanitize_callback' => 'sanitize_text_field',
        'default'			=> 	$options['contact_section_title'],
        'transport'			=>'postMessage'
    ) 
);

$wp_customize->add_control('whole_theme_options[contact_section_title]',
    array(
        'label'             => esc_html__( 'Section Title', 'whole' ),
        'section'           => 'whole_contact_section',
        'type'              => 'text',
        'active_callback'	=> 'whole_is_contact_section_enable',
    )
);

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'whole_theme_options[contact_section_title]',
		array(
			'selector'            => '#whole_contact div:nth-child(1) h2.section-title',
			'settings'            => 'whole_theme_options[contact_section_title]',
			'fallback_refresh'    => true,
			'container_inclusive' => false,
			'render_callback'     => 'whole_contact_section_title_partial',
		) 
	);
}

// contact image setting and control.
$wp_customize->add_setting( 'whole_theme_options[contact_bg_image]',
	array(
		'sanitize_callback' => 'whole_sanitize_image'
	)
);

$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize,
	'whole_theme_options[contact_bg_image]',
		array(
			'label'       		=> esc_html__( 'Backgroung Image', 'whole' ),
			'description' 		=> sprintf( esc_html__( 'Recommended size: %1$dpx x %2$dpx ', 'whole' ), 512, 520 ),
			'section'     		=> 'whole_contact_section',
			'active_callback'	=> 'whole_is_contact_section_enable',
		)
	)
);

// contact section title control and setting
$wp_customize->add_setting( 'whole_theme_options[contact_content_title]',
    array(
        'sanitize_callback' => 'sanitize_text_field',
        'default'			=> 	$options['contact_content_title'],
        'transport'			=>'postMessage'
    ) 
);

$wp_customize->add_control('whole_theme_options[contact_content_title]',
    array(
        'label'             => esc_html__( 'Content Title', 'whole' ),
        'section'           => 'whole_contact_section',
        'type'              => 'text',
        'active_callback'	=> 'whole_is_contact_section_enable',
    )
);

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'whole_theme_options[contact_content_title]',
		array(
			'selector'            => '#whole_contact article:nth-child(1) h2.entry-title',
			'settings'            => 'whole_theme_options[contact_content_title]',
			'fallback_refresh'    => true,
			'container_inclusive' => false,
			'render_callback'     => 'whole_contact_content_title_partial',
		) 
	);
}

// contact section title control and setting
$wp_customize->add_setting( 'whole_theme_options[contact_content_description]',
    array(
        'sanitize_callback' => 'wp_kses_post',
        'default'			=> 	$options['contact_content_description'],
        'transport'			=>'postMessage'
    ) 
);

$wp_customize->add_control('whole_theme_options[contact_content_description]',
    array(
        'label'             => esc_html__( 'Content Description', 'whole' ),
        'section'           => 'whole_contact_section',
        'type'              => 'textarea',
        'active_callback'	=> 'whole_is_contact_section_enable',
    )
);

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'whole_theme_options[contact_content_description]',
		array(
			'selector'            => '#whole_contact article:nth-child(1) .entry-content p',
			'settings'            => 'whole_theme_options[contact_content_description]',
			'fallback_refresh'    => true,
			'container_inclusive' => false,
			'render_callback'     => 'whole_contact_content_description_partial',
		) 
	);
}


// contact image setting and control.
$wp_customize->add_setting( 'whole_theme_options[contact_image]',
	array(
		'sanitize_callback' => 'whole_sanitize_image'
	)
);

$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize,
	'whole_theme_options[contact_image]',
		array(
			'label'       		=> esc_html__( 'Content Image', 'whole' ),
			'description' 		=> sprintf( esc_html__( 'Recommended size: %1$dpx x %2$dpx ', 'whole' ), 512, 520 ),
			'section'     		=> 'whole_contact_section',
			'active_callback'	=> 'whole_is_contact_section_enable',
		)
	)
);

// team multiple input setting and control
$wp_customize->add_setting( 'whole_theme_options[contact_social]',
    array(
        'sanitize_callback' => 'sanitize_text_field'
    )
);

$wp_customize->add_control( new Whole_Multi_Input_Custom_Control( $wp_customize,
    'whole_theme_options[contact_social]',
        array(
            'label'           => sprintf( esc_html__( 'Social Link %d', 'whole' ), $i ),
            'button_text'	  => esc_html__( 'Add Social Link', 'whole' ),
            'section'         => 'whole_contact_section',
            'active_callback' => 'whole_is_contact_section_enable',
            'type'			  => 'multi-input'
        )
    )
);

// contact section title control and setting
$wp_customize->add_setting( 'whole_theme_options[contact_contact_title]',
    array(
        'sanitize_callback' => 'sanitize_text_field',
        'default'			=> 	$options['contact_contact_title'],
        'transport'			=>'postMessage'
    ) 
);

$wp_customize->add_control('whole_theme_options[contact_contact_title]',
    array(
        'label'             => esc_html__( 'Contact Title', 'whole' ),
        'section'           => 'whole_contact_section',
        'type'              => 'text',
        'active_callback'	=> 'whole_is_contact_section_enable',
    )
);

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'whole_theme_options[contact_contact_title]',
		array(
			'selector'            => '#whole_contact article:nth-child(2) h2.section-title',
			'settings'            => 'whole_theme_options[contact_contact_title]',
			'fallback_refresh'    => true,
			'container_inclusive' => false,
			'render_callback'     => 'whole_contact_contact_title_partial',
		) 
	);
}

// contact section title control and setting
$wp_customize->add_setting( 'whole_theme_options[contact_contact_description]',
    array(
        'sanitize_callback' => 'wp_kses_post',
        'default'			=> 	$options['contact_contact_description'],
        'transport'			=>'postMessage'
    ) 
);

$wp_customize->add_control('whole_theme_options[contact_contact_description]',
    array(
        'label'             => esc_html__( 'Contact Descrption', 'whole' ),
        'section'           => 'whole_contact_section',
        'type'              => 'textarea',
        'active_callback'	=> 'whole_is_contact_section_enable',
    )
);

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'whole_theme_options[contact_contact_description]',
		array(
			'selector'            => '#whole_contact article:nth-child(2) .entry-content p',
			'settings'            => 'whole_theme_options[contact_contact_description]',
			'fallback_refresh'    => true,
			'container_inclusive' => false,
			'render_callback'     => 'whole_contact_contact_description_partial',
		) 
	);
}

// contact section title control and setting
$wp_customize->add_setting( 'whole_theme_options[contact_section_shortcode]',
    array(
        'sanitize_callback' => 'sanitize_text_field',
        'transport'			=>'refresh'
    ) 
);

$wp_customize->add_control('whole_theme_options[contact_section_shortcode]',
    array(
        'label'             => esc_html__( 'Contact Shortcode', 'whole' ),
        'section'           => 'whole_contact_section',
        'type'              => 'text',
        'active_callback'	=> 'whole_is_contact_section_enable',
    )
);