<?php
/**
 * Hero Banner Section options
 *
 * @package Theme Palace
 * @subpackage  Whole
 * @since  Whole 1.0.0
 */

// Add Hero Banner section
$wp_customize->add_section( 'whole_hero_banner_section',
	array(
		'title'             => esc_html__( 'Hero Banner','whole' ),
		'description'       => esc_html__( 'Hero Banner Section options.', 'whole' ),
		'panel'             => 'whole_front_page_panel',
	)
);

// Hero Banner content enable control and setting
$wp_customize->add_setting( 'whole_theme_options[hero_banner_section_enable]', 
	array(
		'default'			=> 	$options['hero_banner_section_enable'],
		'sanitize_callback' => 'whole_sanitize_switch_control',
	) 
);

$wp_customize->add_control( new  Whole_Switch_Control( $wp_customize,
	'whole_theme_options[hero_banner_section_enable]',
		array(
			'label'             => esc_html__( 'Hero Banner Section Enable', 'whole' ),
			'section'           => 'whole_hero_banner_section',
			'on_off_label' 		=> whole_switch_options(),
		)
	)
);

// Hero Banner autoplay enable control and setting
$wp_customize->add_setting( 'whole_theme_options[hero_banner_autoplay_enable]',
	array(
		'default'			=> 	$options['hero_banner_autoplay_enable'],
		'sanitize_callback' => 'whole_sanitize_switch_control',
	)
);

$wp_customize->add_control( new  Whole_Switch_Control( $wp_customize,
	'whole_theme_options[hero_banner_autoplay_enable]',
		array(
			'label'             => esc_html__( 'Hero Banner Autoplay Enable', 'whole' ),
			'section'           => 'whole_hero_banner_section',
			'active_callback'   => 'whole_is_hero_banner_section_enable',
			'on_off_label' 		=> whole_switch_options(),
		)
	)
);


for ( $i = 1; $i <= $options['hero_banner_count']; $i++ ) :

	// slider pages drop down chooser control and setting
	$wp_customize->add_setting( 'whole_theme_options[hero_banner_content_page_'. $i .']', 
		array(
			'sanitize_callback' => 'whole_sanitize_page',
		)
	);

	$wp_customize->add_control( new  Whole_Dropdown_Chooser( $wp_customize,
		'whole_theme_options[hero_banner_content_page_'. $i .']', 
			array(
				'label'             => sprintf(esc_html__( 'Select Page: %d', 'whole'), $i ),
				'section'           => 'whole_hero_banner_section',
				'choices'			=> whole_page_choices(),
				'active_callback'	=> 'whole_is_hero_banner_section_enable',
			)
		)
	);

	// Whole_Customize_Horizontal_Line
    $wp_customize->add_setting('whole_theme_options[hero_banner_separator'. $i .']',
		array(
			'sanitize_callback'      => 'whole_sanitize_html',
		)
	);

    $wp_customize->add_control(new Whole_Customize_Horizontal_Line($wp_customize,
		'whole_theme_options[hero_banner_separator'. $i .']',
			array(
				'active_callback'       => 'whole_is_hero_banner_section_enable',
				'type'                  =>'hr',
				'section'               =>'whole_hero_banner_section',
			)
		)
	);

endfor;

//hero_banner_btn_txt
$wp_customize->add_setting('whole_theme_options[hero_banner_btn_txt]',
    array(
        'sanitize_callback' => 'sanitize_text_field',
        'transport'			=> 'postMessage',
        'default'           => $options['hero_banner_btn_txt'],
    )
);

$wp_customize->add_control('whole_theme_options[hero_banner_btn_txt]',
    array(
        'section'			=> 'whole_hero_banner_section',
        'label'				=> esc_html__( 'Button Label:', 'whole' ),
        'type'          	=>'text',
        'active_callback' 	=> 'whole_is_hero_banner_section_enable'
    )
);

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'whole_theme_options[hero_banner_btn_txt]',
		array(
			'selector'            => '#whole_hero_banner div.read-more a:nth-child(1)',
			'settings'            => 'whole_theme_options[hero_banner_btn_txt]',
			'fallback_refresh'    => true,
			'container_inclusive' => false,
			'render_callback'     => 'whole_hero_banner_btn_txt_partial',
		) 
	);
}

//hero_banner_btn_txt
$wp_customize->add_setting('whole_theme_options[hero_banner_alt_btn_txt]',
    array(
        'sanitize_callback' => 'sanitize_text_field',
        'transport'			=> 'postMessage',
        'default'           => $options['hero_banner_alt_btn_txt'],
    )
);

$wp_customize->add_control('whole_theme_options[hero_banner_alt_btn_txt]',
    array(
        'section'			=> 'whole_hero_banner_section',
        'label'				=> esc_html__( 'Alt Button Label:', 'whole' ),
        'type'          	=>'text',
        'active_callback' 	=> 'whole_is_hero_banner_section_enable'
    )
);

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'whole_theme_options[hero_banner_alt_btn_txt]',
		array(
			'selector'            => '#whole_hero_banner div.read-more a:nth-child(2)',
			'settings'            => 'whole_theme_options[hero_banner_alt_btn_txt]',
			'fallback_refresh'    => true,
			'container_inclusive' => false,
			'render_callback'     => 'whole_hero_banner_alt_btn_txt_partial',
		) 
	);
}

// about btn link setting and control
$wp_customize->add_setting( 'whole_theme_options[hero_banner_alt_btn_url]',
	array(
		'sanitize_callback' => 'esc_url_raw',
	)
);

$wp_customize->add_control( 'whole_theme_options[hero_banner_alt_btn_url]',
	array(
		'label'           	=> esc_html__( 'Alt Button URL', 'whole' ),
		'section'        	=> 'whole_hero_banner_section',
		'active_callback' 	=> 'whole_is_hero_banner_section_enable',
		'type'				=> 'url',
	)
);