<?php
/**
 * Projects Section options
 *
 * @package Theme Palace
 * @subpackage Whole
 * @since Whole 1.0.0
 */

// Add Projects section
$wp_customize->add_section( 'whole_projects_section',
	array(
		'title'             => esc_html__( 'Projects','whole' ),
		'description'       => esc_html__( 'Projects  Section options.', 'whole' ),
        'panel'             => 'whole_front_page_panel',
		
	)
);

// Projects content enable control and setting
$wp_customize->add_setting( 'whole_theme_options[projects_section_enable]',
	array(
		'default'			=> 	$options['projects_section_enable'],
		'sanitize_callback' => 'whole_sanitize_switch_control',
	)
);

$wp_customize->add_control( new Whole_Switch_Control( $wp_customize,
	'whole_theme_options[projects_section_enable]',
		array(
			'label'             => esc_html__( 'Projects Section Enable', 'whole' ),
			'section'           => 'whole_projects_section',
			'on_off_label' 		=> whole_switch_options(),
		)
	)
);

// about btn title setting and control
$wp_customize->add_setting( 'whole_theme_options[projects_title]',
	array(
		'default'			=> 	$options['projects_title'],
		'sanitize_callback' => 'sanitize_text_field',
		'transport'			=> 'postMessage',
	)
);

$wp_customize->add_control( 'whole_theme_options[projects_title]',
	array(
		'label'           	=> esc_html__( 'Section Title', 'whole' ),
		'section'        	=> 'whole_projects_section',
		'active_callback' 	=> 'whole_is_projects_section_enable',
		'type'				=> 'text',
	)
);

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'whole_theme_options[projects_title]',
		array(
			'selector'            => '#whole_projects h2.section-title',
			'settings'            => 'whole_theme_options[projects_title]',
			'container_inclusive' => false,
			'fallback_refresh'    => true,
			'render_callback'     => 'whole_projects_title_partial',
		)
	);
}

// about image setting and control.
$wp_customize->add_setting( 'whole_theme_options[projects_image]',
	array(
		'sanitize_callback' => 'whole_sanitize_image'
	)
);

$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize,
	'whole_theme_options[projects_image]',
		array(
			'label'       		=> esc_html__( 'Background Image', 'whole' ),
			'description' 		=> sprintf( esc_html__( 'Recommended size: %1$dpx x %2$dpx ', 'whole' ), 512, 520 ),
			'section'     		=> 'whole_projects_section',
			'active_callback'	=> 'whole_is_projects_section_enable',
		)
	)
);


for ( $i = 1; $i <= $options['projects_count']; $i++ ) :


	// slider posts drop down chooser control and setting
	$wp_customize->add_setting( 'whole_theme_options[projects_content_post_'. $i .']', 
		array(
			'sanitize_callback' => 'whole_sanitize_page',
		)
	);

	$wp_customize->add_control( new  Whole_Dropdown_Chooser( $wp_customize,
		'whole_theme_options[projects_content_post_'. $i .']',
			array(
				'label'             => sprintf(esc_html__( 'Select Post : %d', 'whole'), $i ),
				'section'           => 'whole_projects_section',
				'choices'			=> whole_post_choices(),
				'active_callback'	=> 'whole_is_projects_section_enable',
			)
		)
	);

	// Whole_Customize_Horizontal_Line
    $wp_customize->add_setting('whole_theme_options[projects_separator'. $i .']',
		array(
			'sanitize_callback'      => 'whole_sanitize_html',
		)
	);

    $wp_customize->add_control(new Whole_Customize_Horizontal_Line($wp_customize,
		'whole_theme_options[projects_separator'. $i .']',
			array(
				'active_callback'       => 'whole_is_projects_section_enable',
				'type'                  =>'hr',
				'section'               =>'whole_projects_section',
			)
		)
	);

endfor;

//projects_btn_txt
$wp_customize->add_setting('whole_theme_options[projects_btn_txt]',
    array(
        'sanitize_callback' => 'sanitize_text_field',
        'transport'			=> 'postMessage',
        'default'           => $options['projects_btn_txt'],
    )
);

$wp_customize->add_control('whole_theme_options[projects_btn_txt]',
    array(
        'section'			=> 'whole_projects_section',
        'label'				=> esc_html__( 'Button Text:', 'whole' ),
        'type'          	=>'text',
        'active_callback' 	=> 'whole_is_projects_section_enable'
    )
);

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'whole_theme_options[projects_btn_txt]',
		array(
			'selector'            => '#whole_projects div.read-more a.btn',
			'settings'            => 'whole_theme_options[projects_btn_txt]',
			'fallback_refresh'    => true,
			'container_inclusive' => false,
			'render_callback'     => 'whole_projects_btn_txt_partial',
		)
	);
}
