<?php
/**
 * Welcome Section options
 *
 * @package Theme Palace
 * @subpackage Whole
 * @since Whole 1.0.0
 */

// Add Welcome section
$wp_customize->add_section( 'whole_welcome_section',
	array(
		'title'             => esc_html__( 'Welcome','whole' ),
		'description'       => esc_html__( 'Welcome Section options.', 'whole' ),
		'panel'             => 'whole_front_page_panel',
	)
);

// Welcome content enable control and setting
$wp_customize->add_setting( 'whole_theme_options[welcome_section_enable]',
	array(
		'default'			=> 	$options['welcome_section_enable'],
		'sanitize_callback' => 'whole_sanitize_switch_control',
	)
);

$wp_customize->add_control( new Whole_Switch_Control( $wp_customize,
	'whole_theme_options[welcome_section_enable]',
		array(
			'label'             => esc_html__( 'Welcome Section Enable', 'whole' ),
			'section'           => 'whole_welcome_section',
			'on_off_label' 		=> whole_switch_options(),
		)
	)
);

// about btn title setting and control
$wp_customize->add_setting( 'whole_theme_options[welcome_title]',
	array(
		'default'			=> 	$options['welcome_title'],
		'sanitize_callback' => 'sanitize_text_field',
		'transport'			=> 'postMessage',
	)
);

$wp_customize->add_control( 'whole_theme_options[welcome_title]',
	array(
		'label'           	=> esc_html__( 'Section Title', 'whole' ),
		'section'        	=> 'whole_welcome_section',
		'active_callback' 	=> 'whole_is_welcome_section_enable',
		'type'				=> 'text',
	)
);

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'whole_theme_options[welcome_title]',
		array(
			'selector'            => '#whole_welcome h2.section-title',
			'settings'            => 'whole_theme_options[welcome_title]',
			'container_inclusive' => false,
			'fallback_refresh'    => true,
			'render_callback'     => 'whole_welcome_title_partial',
		)
	);
}

// long Excerpt length setting and control.
$wp_customize->add_setting( 'whole_theme_options[welcome_excerpt_length]',
	array(
		'sanitize_callback' => 'whole_sanitize_number_range',
		'validate_callback' => 'whole_validate_long_excerpt',
		'default'			=> $options['welcome_excerpt_length'],
	)
);

$wp_customize->add_control( 'whole_theme_options[welcome_excerpt_length]',
	array(
		'label'       		=> esc_html__( 'Excerpt Length', 'whole' ),
		'description' 		=> esc_html__( 'Total description words to be displayed in about posts.', 'whole' ),
		'section'     		=> 'whole_welcome_section',
		'type'        		=> 'number',
		'input_attrs' 		=> array(
			'style'       => 'width: 80px;',
			'max'         => 100,
			'min'         => 1,
		),
		'active_callback' 	=> 'whole_is_welcome_section_enable',
	)
);

// about pages drop down chooser control and setting
$wp_customize->add_setting( 'whole_theme_options[welcome_content_page]',
	array(
		'sanitize_callback' => 'whole_sanitize_page',
	)
);

$wp_customize->add_control( new Whole_Dropdown_Chooser( $wp_customize,
	'whole_theme_options[welcome_content_page]',
		array(
			'label'             => esc_html__( 'Select Page', 'whole' ),
			'section'           => 'whole_welcome_section',
			'choices'			=> whole_page_choices(),
			'active_callback'	=> 'whole_is_welcome_section_enable',
		)
	)
);

// about btn title setting and control
$wp_customize->add_setting( 'whole_theme_options[welcome_btn_title]',
	array(
		'default'			=> 	$options['welcome_btn_title'],
		'sanitize_callback' => 'sanitize_text_field',
		'transport'			=> 'postMessage',
	)
);

$wp_customize->add_control( 'whole_theme_options[welcome_btn_title]',
	array(
		'label'           	=> esc_html__( 'Button Label', 'whole' ),
		'section'        	=> 'whole_welcome_section',
		'active_callback' 	=> 'whole_is_welcome_section_enable',
		'type'				=> 'text',
	)
);

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'whole_theme_options[welcome_btn_title]',
		array(
			'selector'            => '#whole_welcome .read-more a.btn',
			'settings'            => 'whole_theme_options[welcome_btn_title]',
			'container_inclusive' => false,
			'fallback_refresh'    => true,
			'render_callback'     => 'whole_welcome_btn_title_partial',
		)
	);
}