<?php
/**
 * Archive options
 *
 * @package Theme Palace
 * @subpackage  Whole
 * @since  Whole 1.0.0
 */

// Add archive section
$wp_customize->add_section( 'whole_archive_section',
	array(
		'title'             => esc_html__( 'Blog/Archive','whole' ),
		'description'       => esc_html__( 'Archive section options.', 'whole' ),
		'panel'             => 'whole_theme_options_panel',
	)
);

// Your latest posts title setting and control.
$wp_customize->add_setting( 'whole_theme_options[your_latest_posts_title]',
	array(
		'default'           => $options['your_latest_posts_title'],
		'sanitize_callback' => 'sanitize_text_field',
	)
);

$wp_customize->add_control( 'whole_theme_options[your_latest_posts_title]',
	array(
		'label'             => esc_html__( 'Your Latest Posts Title', 'whole' ),
		'description'       => esc_html__( 'This option only works if Static Front Page is set to "Your latest posts."', 'whole' ),
		'section'           => 'whole_archive_section',
		'type'				=> 'text',
		'active_callback'	=> function( $control ) {
			return !(
				whole_is_static_homepage_enable( $control )
			);
		}
	)
);

// Archive tag category setting and control.
$wp_customize->add_setting( 'whole_theme_options[hide_category]',
	array(
		'default'           => $options['hide_category'],
		'sanitize_callback' => 'whole_sanitize_switch_control',
	)
);

$wp_customize->add_control( new  Whole_Switch_Control( $wp_customize,
	'whole_theme_options[hide_category]',
		array(
			'label'             => esc_html__( 'Hide Category', 'whole' ),
			'section'           => 'whole_archive_section',
			'on_off_label' 		=> whole_hide_options(),
		)
	)
);

//archive_btn_txt
$wp_customize->add_setting('whole_theme_options[archive_btn_txt]',
    array(
        'sanitize_callback' => 'sanitize_text_field',
        'transport'			=> 'postMessage',
        'default'           => $options['archive_btn_txt'],
    )
);

$wp_customize->add_control('whole_theme_options[archive_btn_txt]',
    array(
        'section'			=> 'whole_archive_section',
        'label'				=> esc_html__( 'Button Text:', 'whole' ),
        'type'          	=>'text',
    )
);

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'whole_theme_options[archive_btn_txt]',
		array(
			'selector'            => '#inner-content-wrapper .archive-blog-wrapper div.read-more a',
			'settings'            => 'whole_theme_options[archive_btn_txt]',
			'fallback_refresh'    => true,
			'container_inclusive' => false,
			'render_callback'     => 'whole_archive_btn_txt_partial',
		) 
	);
}
