<?php
/**
 * Theme Palace options
 *
 * @package Theme Palace
 * @subpackage  Whole
 * @since  Whole 1.0.0
 */

/**
 * List of pages for page choices.
 * @return Array Array of page ids and name.
 */
function whole_page_choices() {
    $pages = get_pages();
    $choices = array();
    $choices[0] = esc_html__( '--Select--', 'whole' );
    foreach ( $pages as $page ) {
        $choices[ $page->ID ] = $page->post_title;
    }
    return  $choices;
}

/**
 * List of posts for post choices.
 * @return Array Array of post ids and name.
 */
function whole_post_choices() {
    $posts = get_posts( array( 'numberposts' => -1 ) );
    $choices = array();
    $choices[0] = esc_html__( '--Select--', 'whole' );
    foreach ( $posts as $post ) {
        $choices[ $post->ID ] = $post->post_title;
    }
    wp_reset_postdata();
    return  $choices;
}

/**
 * List of products for post choices.
 * @return Array Array of post ids and name.
 */
function whole_product_choices() {
    $posts = get_posts( array( 'numberposts' => -1, 'post_type' => 'product' ) );
    $choices = array();
    $choices[0] = esc_html__( '--Select--', 'whole' );
    foreach ( $posts as $post ) {
        $choices[ $post->ID ] = $post->post_title;
    }
    return  $choices;
}

/**
 * List of category for category choices.
 * @return Array Array of post ids and name.
 */
function whole_category_choices() {
    $tax_args = array(
        'hierarchical' => 0,
        'taxonomy'     => 'category',
    );
    $taxonomies = get_categories( $tax_args );
    $choices = array();
    $choices[0] = esc_html__( '--Select--', 'whole' );
    foreach ( $taxonomies as $tax ) {
        $choices[ $tax->term_id ] = $tax->name;
    }
    return  $choices;
}

/**
 * List of category for category choices.
 * @return Array Array of post ids and name.
 */
function whole_product_category_choices() {
    $tax_args = array(
        'hierarchical' => 0,
        'taxonomy'     => 'product_cat',
    );
    $taxonomies = get_categories( $tax_args );
    $choices = array();
    $choices[0] = esc_html__( '--Select--', 'whole' );
    foreach ( $taxonomies as $tax ) {
        $choices[ $tax->term_id ] = $tax->name;
    }
    return  $choices;
}

if ( ! function_exists( 'whole_site_layout' ) ) :
    /**
     * Site Layout
     * @return array site layout options
     */
    function whole_site_layout() {
        $whole_site_layout = array(
            'wide'          => esc_url( get_template_directory_uri() . '/assets/images/full.png' ),
            'boxed-layout'  => esc_url( get_template_directory_uri() . '/assets/images/boxed.png' ),
        );

        $output = apply_filters( 'whole_site_layout', $whole_site_layout );
        return $output;
    }
endif;

if ( ! function_exists( 'whole_selected_sidebar' ) ) :
    /**
     * Sidebars options
     * @return array Sidbar positions
     */
    function whole_selected_sidebar() {
        $whole_selected_sidebar = array(
            'sidebar-1'             => esc_html__( 'Default Sidebar', 'whole' ),
            'optional-sidebar'      => esc_html__( 'Optional Sidebar 1', 'whole' ),
        );

        $output = apply_filters( 'whole_selected_sidebar', $whole_selected_sidebar );

        return $output;
    }
endif;


if ( ! function_exists( 'whole_global_sidebar_position' ) ) :
    /**
     * Global Sidebar position
     * @return array Global Sidebar positions
     */
    function whole_global_sidebar_position() {
        $whole_global_sidebar_position = array(
            'right-sidebar' => esc_url( get_template_directory_uri() . '/assets/images/right.png' ),
            'no-sidebar'    => esc_url( get_template_directory_uri() . '/assets/images/full.png' ),
        );

        $output = apply_filters( 'whole_global_sidebar_position', $whole_global_sidebar_position );

        return $output;
    }
endif;


if ( ! function_exists( 'whole_sidebar_position' ) ) :
    /**
     * Sidebar position
     * @return array Sidbar positions
     */
    function whole_sidebar_position() {
        $whole_sidebar_position = array(
            'right-sidebar'         => esc_url( get_template_directory_uri() . '/assets/images/right.png' ),
            'no-sidebar-content'    => esc_url( get_template_directory_uri() . '/assets/images/boxed.png' ),
        );

        $output = apply_filters( 'whole_sidebar_position', $whole_sidebar_position );

        return $output;
    }
endif;

if ( ! function_exists( 'whole_pagination_options' ) ) :
    /**
     * Pagination
     * @return array site pagination options
     */
    function whole_pagination_options() {
        $whole_pagination_options = array(
            'numeric'   => esc_html__( 'Numeric', 'whole' ),
            'default'   => esc_html__( 'Default(Older/Newer)', 'whole' ),
        );

        $output = apply_filters( 'whole_pagination_options', $whole_pagination_options );

        return $output;
    }
endif;


if ( ! function_exists( 'whole_switch_options' ) ) :
    /**
     * List of custom Switch Control options
     * @return array List of switch control options.
     */
    function whole_switch_options() {
        $arr = array(
            'on'        => esc_html__( 'Enable', 'whole' ),
            'off'       => esc_html__( 'Disable', 'whole' )
        );
        return apply_filters( 'whole_switch_options', $arr );
    }
endif;

if ( ! function_exists( 'whole_hide_options' ) ) :
    /**
     * List of custom Switch Control options
     * @return array List of switch control options.
     */
    function whole_hide_options() {
        $arr = array(
            'on'        => esc_html__( 'Yes', 'whole' ),
            'off'       => esc_html__( 'No', 'whole' )
        );
        return apply_filters( 'whole_hide_options', $arr );
    }
endif;

if ( ! function_exists( 'whole_sortable_sections' ) ) :
    /**
     * List of sections Control options
     * @return array List of Sections control options.
     */
    function whole_sortable_sections() {
        $options = whole_get_theme_options();
  
        $sections = array(
            'hero_banner'               => esc_html__( 'Hero Banner', 'whole' ),
            'projects'                  => esc_html__( 'Album', 'whole' ),
            'call_to_action'            => esc_html__( 'Promotion', 'whole' ),
            'contact'                   => esc_html__( 'Contact', 'whole' ),
            'welcome'                   => esc_html__( 'Welcome', 'whole' ),
        );
         
        return apply_filters( 'whole_sortable_sections', $sections );
    }
endif;


if ( ! function_exists( 'whole_hero_banner_content_type' ) ) :
    /**
     * Product Options
     * @return array site product options
     */
    function whole_hero_banner_content_type() {
        $whole_hero_banner_content_type = array(
            'page' 		=> esc_html__( 'Page', 'whole' ),
			'post' 		=> esc_html__( 'Post', 'whole' ),
			'category' 	=> esc_html__( 'Category', 'whole' ),
        );

        $output = apply_filters( 'whole_hero_banner_content_type', $whole_hero_banner_content_type );

        return $output;
    }
endif;