<?php
/**
 * Banner section
 *
 * This is the template for the content of call_to_action section
 *
 * @package Theme Palace
 * @subpackage Whole
 * @since Whole 1.0.0
 */
if ( ! function_exists( 'whole_add_call_to_action_section' ) ) :
    /**
    * Add call_to_action section
    *
    *@since Whole 1.0.0
    */
    function whole_add_call_to_action_section() {
    	$options = whole_get_theme_options();
        // Check if call_to_action is enabled on frontpage
        $call_to_action_enable = apply_filters( 'whole_section_status', true, 'call_to_action_section_enable' ) ;
        
        if ( true !== $call_to_action_enable ) {
            return false;
        }
        // Get call_to_action section details
        $section_details = array();
        $section_details = apply_filters( 'whole_filter_call_to_action_section_details', $section_details );
        if ( empty( $section_details ) ) {
            return ;
        }
        // Render call_to_action section now.
        whole_render_call_to_action_section( $section_details );
    }
endif;

if ( ! function_exists( 'whole_get_call_to_action_section_details' ) ) :
    /**
    * call_to_action section details.
    *
    * @since Whole 1.0.0
    * @param array $input call_to_action section details.
    */
    function whole_get_call_to_action_section_details( $input ) {
        $options = whole_get_theme_options();

        // Content type.
        $call_to_action_content_type  = $options['call_to_action_content_type'];
        
        $content = array();
        $page_id = '';
        if ( ! empty( $options['call_to_action_content_page'] ) )
            $page_id = isset($options['call_to_action_content_page']) ? $options['call_to_action_content_page'] : '' ;
        $args = array(
            'post_type'             => 'page',
            'p'                     =>  absint( $page_id ),
            'ignore_sticky_posts'   => true,
        );

        // Run The Loop.
        $query = new WP_Query( $args );
        if ( $query->have_posts() ) : 
            while ( $query->have_posts() ) : $query->the_post();
                $page_post['id']        = get_the_id();
                $page_post['excerpt']   = whole_trim_content($options['call_to_action_excerpt_length']);
                $page_post['title']     = get_the_title();
                $page_post['url']       = get_the_permalink( );
                $page_post['image']     = !empty(get_the_post_thumbnail_url( )) ? get_the_post_thumbnail_url( get_the_id(), 'medium_large' ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-600x450.jpg';
                // Push to the main array.
                array_push( $content, $page_post );
            endwhile;
        endif;
        wp_reset_postdata();


        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// call_to_action section content details.
add_filter( 'whole_filter_call_to_action_section_details', 'whole_get_call_to_action_section_details' );


if ( ! function_exists( 'whole_render_call_to_action_section' ) ) :
  /**
   * Start call_to_action section
   *
   * @return string call_to_action content
   * @since Whole 1.0.0
   *
   */
   function whole_render_call_to_action_section( $content_details = array() ) {
        $options        = whole_get_theme_options();
        $call_to_action_bg_image   = empty( $options['call_to_action_bg_image'] ) ? '' : $options['call_to_action_bg_image'] ;
        $call_to_action_content_subtitle     = ! empty( $options['call_to_action_content_subtitle'] ) ? $options['call_to_action_content_subtitle'] : '';
        
        if ( empty( $content_details ) ) {
            return;
        } ?>
        <?php $content = $content_details[0];?>

        <div id="whole_call_to_action" class="relative">
            <?php if(!empty($call_to_action_bg_image)) : ?>
                <div class="cta-banner section-banner" style="background-image: url('<?php echo esc_url($call_to_action_bg_image); ?>');">
                    <div class="overlay"></div>
                <?php endif; ?>
                <div class="wrapper">
                    <div class="section-header">
                        <h2 class="section-title"><?php echo esc_html( $options['call_to_action_title'] ); ?></h2>
                    </div>
                </div>
            <?php if(!empty($call_to_action_bg_image)) echo '</div>'; ?>

            <div class="cta-wrapper">
                <div class="wrapper">
                    <article>
                        <div class="featured-image" style="background-image: url('<?php echo esc_url( $content['image'] ); ?>');"></div>
                        <div class="entry-container">
                            <div class="section-header">
                                <h2 class="section-title"><?php echo esc_html( $content['title'] ); ?></h2>
                            </div>
                            <div class="entry-header">
                                <h2 class="entry-title"><?php echo esc_html( $call_to_action_content_subtitle ); ?></h2>
                            </div>
                            <div class="entry-content">
                                <span><?php echo wp_kses_post( $content['excerpt'] ); ?></span>
                            </div>                        <?php 
                            $page_ids = ! empty( $options['call_to_action_content_multitple_page'] ) ? $options['call_to_action_content_multitple_page'] : array();                                  
                            $content_pages = get_posts(['include' => $page_ids, 'post_type' => 'page']); ?>

                            <ol  class="cta-list">
                                <?php foreach( $content_pages as $i=>$page ){
                                    echo '<li><a href="'.get_page_link( $page->ID ).'">'.$page->post_title.'</a></li>';
                                } ?>
                            </ol>

                        </div>
                    </article>
                </div>
            </div>
        </div><!-- #whole_call_to_action -->
        
    <?php
    }    
endif;
