<?php
/**
 * Banner section
 *
 * This is the template for the content of contact section
 *
 * @package Theme Palace
 * @subpackage  Whole
 * @since  Whole 1.0.0
 */
if ( ! function_exists( 'whole_add_contact_section' ) ) :
    /**
    * Add contact section
    *
    *@since  Whole 1.0.0
    */
    function whole_add_contact_section() {
    	$options = whole_get_theme_options();
        // Check if contact is enabled on frontpage
        $contact_enable = apply_filters( 'whole_section_status', true, 'contact_section_enable' );

        if ( true !== $contact_enable ) {
            return false;
        }
        // Get contact section details
        $section_details = array();
        $section_details = apply_filters( 'whole_filter_contact_section_details', $section_details );
        if ( empty( $section_details ) ) {
            return ;
        }

        // Render contact section now.
        whole_render_contact_section( $section_details );
    }
endif;

if ( ! function_exists( 'whole_get_contact_section_details' ) ) :
    /**
    * contact section details.
    *
    * @since  Whole 1.0.0
    * @param array $input contact section details.
    */
    function whole_get_contact_section_details( $input ) {
        $options = whole_get_theme_options();

        $content = array();
        $content['contact_section_shortcode']   = (!empty($options['contact_section_shortcode'])) ? $options['contact_section_shortcode'] : '';
        $content['contact_section_title']       = (!empty($options['contact_section_title'])) ? $options['contact_section_title'] : esc_html__('Stay In Touch!!', 'whole');
        $content['contact_section_subtitle']    = (!empty($options['contact_section_subtitle'])) ? $options['contact_section_subtitle'] : esc_html__('CONTACT US', 'whole');

        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// contact section content details.
add_filter( 'whole_filter_contact_section_details', 'whole_get_contact_section_details' );


if ( ! function_exists( 'whole_render_contact_section' ) ) :
  /**
   * Start contact section
   *
   * @return string contact content
   * @since  Whole 1.0.0
   *
   */
   function whole_render_contact_section( $content_details = array() ) {
        $options        = whole_get_theme_options();
        $contact_bg_image   = empty( $options['contact_bg_image'] ) ? '' : $options['contact_bg_image'] ;
        $contact_image   = empty( $options['contact_image'] ) ? get_template_directory_uri( ).'/assets/uploads/no-featured-image-600x450.jpg' : $options['contact_image'] ;
        
        if ( empty( $content_details ) ) {
            return;
        } ?>
        
            <div id="whole_contact" class="relative">
                <?php if(!empty($image)) : ?>
                    <div class="contact-banner section-banner" style="background-image: url('<?php echo esc_url($contact_bg_image); ?>');">
                        <div class="overlay"></div>
                    <?php endif; ?>
                    <div class="wrapper">
                        <div class="section-header">
                            <h2 class="section-title"><?php echo esc_html( $options['contact_section_title'] ); ?></h2>
                        </div>
                    </div>
                <?php if(!empty($image)) echo '</div>'; ?>

                <div class="wrapper">
                    <div class="contact-wrapper clear">
                        <article>
                            <div class="entry-container">
                                <div class="featured-image" style="background-image: url('<?php echo esc_url($contact_image); ?>');"></div>
                                <div class="entry-header">
                                    <h2 class="entry-title"><?php echo esc_html($options['contact_content_title']);?></h2>
                                </div>
                                <div class="entry-content">
                                    <p><?php echo wp_kses_post($options['contact_content_description']);?></p>
                                </div>
                                <?php if ( ! empty( $options['contact_social'] ) ) : $social = explode( '|', $options['contact_social'] ); ?>
                                    <div class="social-icons">
                                        <ul>
                                            <?php foreach( $social as $social_link ) : ?>
                                                <li>
                                                    <a href="<?php echo esc_url( $social_link ); ?>">
                                                        <?php echo whole_return_social_icon( $social_link ); ?>
                                                    </a>
                                                </li>
                                            <?php endforeach; ?>
                                        </ul>
                                    </div><!-- .social-icons -->
                                <?php endif; ?>
                            </div>
                        </article>

                        <article>
                            <div class="entry-container">
                                <div class="section-header">
                                    <h2 class="section-title"><?php echo esc_html($options['contact_contact_title']);?></h2>
                                </div>
                                <div class="entry-content">
                                    <p><?php echo wp_kses_post($options['contact_contact_description']);?></p>
                                </div>
                            </div>
                            <?php echo do_shortcode( wp_kses_post( $content_details['contact_section_shortcode'] ) );  ?>

                        </article>
                    </div>
                </div>
            </div><!-- #whole_contact -->
  
        <?php 
    }    
endif; ?>
