<?php
/**
 * Banner section
 *
 * This is the template for the content of hero hero_banner section
 *
 * @package Theme Palace
 * @subpackage  Whole
 * @since  Whole 1.0.0
 */
if ( ! function_exists( 'whole_add_hero_banner_section' ) ) :
    /**
    * Add hero_banner section
    *
    *@since  Whole 1.0.0
    */
    function whole_add_hero_banner_section() {
    	$options = whole_get_theme_options();
        // Check if hero_banner is enabled on frontpage
        $hero_banner_enable = apply_filters( 'whole_section_status', true, 'hero_banner_section_enable' );

        if ( true !== $hero_banner_enable ) {
            return false;
        }
        // Get hero_banner section details
        $section_details = array();
        $section_details = apply_filters( 'whole_filter_hero_banner_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render hero_banner section now.
        whole_render_hero_banner_section( $section_details );
}

endif;

if ( ! function_exists( 'whole_get_hero_banner_section_details' ) ) :
    /**
    * hero_banner section details.
    *
    * @since  Whole 1.0.0
    * @param array $input hero_banner section details.
    */
    function whole_get_hero_banner_section_details( $input ) {
        $options = whole_get_theme_options();

        // Content type.
        $hero_banner_content_type    = $options['hero_banner_content_type'];
        $hero_banner_count           = ! empty( $options['hero_banner_count'] ) ? $options['hero_banner_count'] : 3;
        
        $content = array();
        $page_ids = array();

        for ( $i = 1; $i <= $hero_banner_count; $i++ ) {
            if ( ! empty( $options['hero_banner_content_page_' . $i] ) )
                $page_ids[] = $options['hero_banner_content_page_' . $i];
        }

        $args = array(
            'post_type'         => 'page',
            'post__in'          => ( array ) $page_ids,
            'posts_per_page'    => absint( $hero_banner_count ),
            'orderby'           => 'post__in',
        );                    

        // Run The Loop.
        $query = new WP_Query( $args );
        if ( $query->have_posts() ) : 
            while ( $query->have_posts() ) : $query->the_post();
                $page_post['id']        = get_the_id();
                $page_post['title']     = get_the_title();
                $page_post['excerpt']   = whole_trim_content(10);
                $page_post['url']       = get_the_permalink( );
                $page_post['image']     = !empty(get_the_post_thumbnail_url( )) ? get_the_post_thumbnail_url( get_the_id(), 'large' ) : '';
                // Push to the main array.
                // Push to the main array.
                array_push( $content, $page_post );
            endwhile;
        endif;
        wp_reset_postdata();

        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// hero_banner section content details.
add_filter( 'whole_filter_hero_banner_section_details', 'whole_get_hero_banner_section_details' );


if ( ! function_exists( 'whole_render_hero_banner_section' ) ) :

  /**
   * Start hero_banner section
   *
   * @return string hero_banner content
   * @since  Whole 1.0.0
   *
   */
   function whole_render_hero_banner_section( $content_details = array() ) {
        $options = whole_get_theme_options();
        $hero_banner_autoplay_enable = ($options['hero_banner_autoplay_enable']) ? 'true' : 'false';

        if ( empty( $content_details ) ) {
            return;
        } ?>

        <div id="whole_hero_banner" class="relative">
            <div class="hero-banner" data-slick='{"slidesToShow": 1, "slidesToScroll": 1, "infinite": true, "speed": 1000, "dots": false, "arrows":false, "autoplay": <?php echo esc_attr($hero_banner_autoplay_enable); ?>, "draggable": true, "fade": true, "adaptiveHeight": false }'>
            <?php foreach($content_details as $i => $content) : ?>
                <article style="background-image:url('<?php echo esc_url($content['image']); ?>');">
                    <div class="overlay"></div>
                    <div class="wrapper">
                        <div class="hero-banner-wrapper">
                            <div class="entry-container">
                                <header class="entry-header">
                                    <h2 class="entry-title"><a href="<?php echo esc_url($content['url']); ?>"><?php echo esc_html($content['title']); ?></a></h2>
                                </header>

                                <div class="entry-content">
                                    <p><?php echo wp_kses_post( $content['excerpt'] ); ?></p>
                                </div><!-- .entry-content -->

                                <?php if(!empty($options['hero_banner_alt_btn_txt']) && !empty($options['hero_banner_btn_txt'])) : ?>
                                    <div class="read-more">
                                        <?php if(!empty($options['hero_banner_alt_btn_txt']) && !empty($options['hero_banner_alt_btn_url'])) : ?>
                                            <a href="<?php echo esc_url($options['hero_banner_alt_btn_url']); ?>" class="btn"><?php echo esc_html($options['hero_banner_alt_btn_txt']); ?></a>
                                            <?php endif; ?>
                                        <?php if( !empty($options['hero_banner_btn_txt'])) : ?>
                                            <a href="<?php echo esc_url($content['url']); ?>" class="btn"><?php echo esc_html($options['hero_banner_btn_txt']); ?></a>
                                        <?php endif; ?>
                                    </div><!-- .read-more -->
                                <?php endif; ?>
                            </div><!-- .entry-container -->
                        </div><!-- .hero-banner-wrapper -->
                    </div><!-- .wrapper -->
                </article>
                <?php endforeach; ?>
            </div>
        </div><!-- #whole_hero_banner -->
          

<?php
    }    
endif;