<?php
/**
 * Projects section
 *
 * This is the template for the content of projects section
 *
 * @package Theme Palace
 * @subpackage Whole
 * @since Whole 1.0.0
 */
if ( ! function_exists( 'whole_add_projects_section' ) ) :
    /**
    * Add projects section
    *
    *@since Whole 1.0.0
    */
    function whole_add_projects_section() {
    	$options = whole_get_theme_options();
        // Check if projects is enabled on frontpage
        $projects_enable = apply_filters( 'whole_section_status', true, 'projects_section_enable' ) ;
        
        if ( true !== $projects_enable ) {
            return false;
        }
        // Get projects section details
        $section_details = array();
        $section_details = apply_filters( 'whole_filter_projects_section_details', $section_details );
        if ( empty( $section_details ) ) {
            return ;
        }

        // Render projects section now.
        whole_render_projects_section( $section_details );
    }
endif;

if ( ! function_exists( 'whole_get_projects_section_details' ) ) :
    /**
    * projects section details.
    *
    * @since Whole 1.0.0
    * @param array $input projects section details.
    */
    function whole_get_projects_section_details( $input ) {
        $options = whole_get_theme_options();

        // Content type.
        $projects_content_type  = $options['projects_content_type'];
        $projects_count           = ! empty( $options['projects_count'] ) ? $options['projects_count'] : 3;
        
        $content = array();
        $post_ids = array();

        for ( $i = 1; $i <= $projects_count; $i++ ) {
            if ( ! empty( $options['projects_content_post_' . $i] ) )
                $post_ids[] = $options['projects_content_post_' . $i];
        }
        
        $args = array(
            'post_type'             => 'post',
            'post__in'              => ( array ) $post_ids,
            'posts_per_page'        => absint( $projects_count ),
            'orderby'               => 'post__in',
            'ignore_sticky_posts'   => true,
        );                    
        
        // Run The Loop.
        $query = new WP_Query( $args );
        if ( $query->have_posts() ) : 
            while ( $query->have_posts() ) : $query->the_post();
                $page_post['id']        = get_the_id();
                $page_post['excerpt']   = whole_trim_content($options['projects_excerpt_length']);
                $page_post['title']     = get_the_title();
                $page_post['url']       = get_the_permalink( );
                $page_post['image']     = !empty(get_the_post_thumbnail_url( )) ? get_the_post_thumbnail_url( get_the_id(), 'medium_large' ) : get_template_directory_uri().'/assets/uploads/no-featured-image-600x450.jpg';
                // Push to the main array.
                array_push( $content, $page_post );
            endwhile;
        endif;
        wp_reset_postdata();

        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// projects section content details.
add_filter( 'whole_filter_projects_section_details', 'whole_get_projects_section_details' );


if ( ! function_exists( 'whole_render_projects_section' ) ) :
  /**
   * Start projects section
   *
   * @return string projects content
   * @since Whole 1.0.0
   *
   */
   function whole_render_projects_section( $content_details = array() ) {
        $options        = whole_get_theme_options();
        $projects_image   = empty( $options['projects_image'] ) ? '' : $options['projects_image'] ;
        
        if ( empty( $content_details ) ) {
            return;
        } ?>

        <div id="whole_projects" class="relative">
            <?php if(!empty($projects_image)) : ?>
                <div class="project-banner section-banner" style="background-image: url('<?php echo esc_url($projects_image); ?>');">
                    <div class="overlay"></div>
                <?php endif; ?>
                <div class="wrapper">
                    <div class="section-header">
                        <h2 class="section-title"><?php echo esc_html( $options['projects_title'] ); ?></h2>
                    </div>
                </div>
            <?php if(!empty($projects_image)) echo '</div>'; ?>

            <div class="wrapper">
                <div class="section-content col-3 clear">
                <?php foreach ( $content_details as $i=>$content ) : ?>
                    <article>
                        <div class="project-container">
                            <div class="featured-image" style="background-image: url('<?php echo esc_url($content['image']); ?>');">
                                <div class="overlay"></div>
                            </div>
                            <div class="entry-container">
                                <header class="entry-header">
                                    <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                                </header>
                                <span class="cat-links">
                                    <?php the_category('', '', $content['id'])?>
                                </span>
                            </div>
                            <?php if( !empty( $content['url'] ) && !empty( $options['projects_btn_txt'] ) ): ?>
                                <div class="read-more">
                                    <a href="<?php echo esc_url( $content['url'] ); ?>" class="btn"><?php echo esc_html( $options['projects_btn_txt'] ); ?></a>
                                </div><!-- .read-more -->
                            <?php endif; ?>
                        </div>
                    </article>
                    <?php endforeach; ?>

                </div>
            </div>
        </div><!-- #whole_projects -->
        
    <?php
    }    
endif;