<?php
/**
 * welcome section
 *
 * This is the template for the content of welcome section
 *
 * @package Theme Palace
 * @subpackage Whole
 * @since Whole 1.0.0
 */
if ( ! function_exists( 'whole_add_welcome_section' ) ) :
    /**
    * Add welcome section
    *
    *@since Whole 1.0.0
    */
    function whole_add_welcome_section() {
    	$options = whole_get_theme_options();
        // Check if welcome is enabled on frontpage
        $welcome_enable = apply_filters( 'whole_section_status', true, 'welcome_section_enable' );

        if ( true !== $welcome_enable ) {
            return false;
        }
        // Get welcome section details
        $section_details = array();
        $section_details = apply_filters( 'whole_filter_welcome_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }
        // Render welcome section now.
        whole_render_welcome_section( $section_details );
    }
endif;

if ( ! function_exists( 'whole_get_welcome_section_details' ) ) :
    /**
    * welcome section details.
    *
    * @since Whole 1.0.0
    * @param array $input welcome section details.
    */
    function whole_get_welcome_section_details( $input ) {
        $options = whole_get_theme_options();

        // Content type.
        $welcome_content_type  = $options['welcome_content_type'];
        
        $content = array();
        $page_id = ! empty( $options['welcome_content_page'] ) ? $options['welcome_content_page'] : '';
        $args = array(
            'post_type'         => 'page',
            'page_id'           => $page_id,
            'posts_per_page'    => 1,
        );                    

        // Run The Loop.
        $query = new WP_Query( $args );
        if ( $query->have_posts() ) : 
            while ( $query->have_posts() ) : $query->the_post();
                $page_post['title']     = get_the_title();
                $page_post['url']       = get_the_permalink();
                $page_post['excerpt']   = whole_trim_content( $options['welcome_excerpt_length'] );
                $page_post['image']  	= has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'medium_large' ) : get_template_directory_uri().'/assets/uploads/no-featured-image-600x450.jpg';

                // Push to the main array.
                array_push( $content, $page_post );
            endwhile;
        endif;
        wp_reset_postdata();
            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// welcome section content details.
add_filter( 'whole_filter_welcome_section_details', 'whole_get_welcome_section_details' );


if ( ! function_exists( 'whole_render_welcome_section' ) ) :
  /**
   * Start welcome section
   *
   * @return string welcome content
   * @since Whole 1.0.0
   *
   */
   function whole_render_welcome_section( $content_details = array() ) {
        $options = whole_get_theme_options();

        if ( empty( $content_details ) ) {
            return;
        } ?>
        
        <div id="whole_welcome" class="relative">
            <div class="wrapper">
                <div class="section-header">
                    <h2 class="section-title"><?php echo esc_html( $options['welcome_title'] ); ?></h2>
                </div>
                <?php foreach ( $content_details as $content ) :  ?>
                <article>
                    <div class="entry-header">
                        <h2 class="entry-title"><?php echo esc_html( $content['title'] ); ?></h2>
                    </div>
                    <div class="entry-content">
                        <p><?php echo wp_kses_post( $content['excerpt'] ); ?></p>
                    </div>

                    <?php if( !empty( $content['url'] ) && !empty( $options['welcome_btn_title'] ) ): ?>
                        <div class="read-more">
                            <a href="<?php echo esc_url( $content['url'] ); ?>" class="btn"><?php echo esc_html( $options['welcome_btn_title'] ); ?></a>
                        </div><!-- .read-more -->
                    <?php endif; ?>
                </article>
                <?php endforeach; ?>
            </div>
        </div><!-- #whole_welcome -->
       
<?php  }

endif;

