<?php
/**
 * Theme Palace basic theme structure hooks
 *
 * This file contains structural hooks.
 *
 * @package Theme Palace
 * @subpackage  Whole
 * @since  Whole 1.0.0
 */

$options = whole_get_theme_options();  


if ( ! function_exists( 'whole_doctype' ) ) :
	/**
	 * Doctype Declaration.
	 *
	 * @since  Whole 1.0.0
	 */
	function whole_doctype() {
	?>
		<!DOCTYPE html>
			<html <?php language_attributes(); ?>>
	<?php
	}
endif;
add_action( 'whole_doctype', 'whole_doctype', 10 );


if ( ! function_exists( 'whole_head' ) ) :
	/**
	 * Header Codes
	 *
	 * @since  Whole 1.0.0
	 *
	 */
	function whole_head() {
		?>
		<meta charset="<?php bloginfo( 'charset' ); ?>">
		<meta name="viewport" content="width=device-width, initial-scale=1">
		<link rel="profile" href="https://gmpg.org/xfn/11">
		<?php if ( is_singular() && pings_open( get_queried_object() ) ) : ?>
			<link rel="pingback" href="<?php echo esc_url( get_bloginfo( 'pingback_url' ) ); ?>">
		<?php endif;
	}
endif;
add_action( 'whole_before_wp_head', 'whole_head', 10 );

if ( ! function_exists( 'whole_page_start' ) ) :
	/**
	 * Page starts html codes
	 *
	 * @since  Whole 1.0.0
	 *
	 */
	function whole_page_start() {
		?>
		<div id="page" class="site">
			<a class="skip-link screen-reader-text" href="#content"><?php esc_html_e( 'Skip to content', 'whole' ); ?></a>
		<?php
	}
endif;
add_action( 'whole_page_start_action', 'whole_page_start', 10 );

if ( ! function_exists( 'whole_page_end' ) ) :
	/**
	 * Page end html codes
	 *
	 * @since  Whole 1.0.0
	 *
	 */
	function whole_page_end() {
		?>
		</div><!-- #page -->
		<?php
	}
endif;
add_action( 'whole_page_end_action', 'whole_page_end', 10 );

if ( ! function_exists( 'whole_site_branding' ) ) :
	/**
	 * Site branding codes
	 *
	 * @since  Whole 1.0.0
	 *
	 */
	function whole_site_branding() {
		$options  = whole_get_theme_options();
		$header_txt_logo_extra = $options['header_txt_logo_extra'];	 ?>

        <div class="menu-overlay"></div>
        <div class="main-menu">
			<div id="top-navigation" class="relative">
				<button class="menu-toggle" aria-controls="secondary-menu" aria-expanded="false" title="<?php _e( 'Top Menu', 'whole' ); ?>">
					<?php
					echo whole_get_svg( array( 'icon' => 'menu', 'class' => 'icon-menu' ) );
					echo whole_get_svg( array( 'icon' => 'close', 'class' => 'icon-menu' ) );
					?>
				</button><!-- .menu-toggle -->
				<div class="wrapper">
					<nav id="secondary-navigation" class="main-navigation" role="navigation">
						<ul id="secondary-menu" class="menu nav-menu" aria-expanded="false">
							<li>
								<?php if(!empty($options['top_bar_phoneNumber'])) : ?>
									<a href="tel:<?php echo esc_attr($options['top_bar_phoneNumber']); ?>">
										<?php echo whole_get_svg( array( 'icon' => 'phone' ) );?>
										<span><?php echo esc_html($options['top_bar_phoneNumber']); ?></span>
									</a>
								<?php endif; ?>
							</li>
							<li>
								<?php if(!empty($options['top_bar_email'])) : ?>
									<a href="mailto:<?php echo esc_attr($options['top_bar_email']); ?>">
										<?php echo whole_get_svg( array( 'icon' => 'envelope' ) );?>
										<span><?php echo esc_html($options['top_bar_email']); ?></span>
									</a>
								<?php endif; ?>
							</li>
							<li>
								<?php if(!empty($options['top_bar_address'])) : ?>
									<a href="#">
										<?php echo whole_get_svg( array( 'icon' => 'map' ) );?>
										<span><?php echo esc_html($options['top_bar_address']); ?></span>
									</a>
								<?php endif; ?>
							</li>
							<li class="social-icons"><?php echo whole_get_social_menu(); ?></li>
						</ul>

						<div class="site-branding-wrapper">
							<?php whole_get_site_branding(); ?>
						</div><!-- .site-branding-wrapper -->

						<div class="icon-wrapper">
							<div class="social-icons"><?php echo whole_get_social_menu(); ?></div>
						</div><!-- .icon-wrapper -->
					</nav><!-- .main-navigation-->
				</div><!-- .wrapper -->
			</div><!-- #top-navigation -->

			<header id="masthead" class="site-header" role="banner">
				<div class="site-branding-container">
					<div class="wrapper">
						<div class="site-branding-wrapper">
							<?php whole_get_site_branding(); ?>
						</div><!-- .site-branding-wrapper -->
					</div>
					<button class="menu-toggle" aria-controls="primary-menu" aria-expanded="false" title="<?php _e( 'Primary Menu', 'whole' ); ?>">
						<?php
							echo whole_get_svg( array( 'icon' => 'menu', 'class' => 'icon-menu' ) );
							echo whole_get_svg( array( 'icon' => 'close', 'class' => 'icon-menu' ) );
						?>
					</button>
					<nav id="site-navigation" class="main-navigation" role="navigation" aria-label="<?php _e( 'Primary Menu', 'whole' ); ?>">
						<?php 
						wp_nav_menu(
							array(
								'theme_location' => 'primary',
								'container' => 'div',
								'menu_class' => 'menu nav-menu',
								'menu_id' => 'primary-menu',
								'echo' => true,
								'fallback_cb' => 'whole_menu_fallback_cb',
								'items_wrap' => '<ul id="%1$s" class="%2$s">%3$s</ul>',
							)
						);
						?>
					</nav><!-- #site-navigation -->
				</div>
			</header><!-- .header-->
		</div>
<?php 
	}
endif;
add_action( 'whole_header_action', 'whole_site_branding', 10 );

if ( ! function_exists( 'whole_content_start' ) ) :
	/**
	 * Site content codes
	 *
	 * @since  Whole 1.0.0
	 *
	 */
	function whole_content_start() {
		?>
		<div id="content" class="site-content">
		<?php
	}
endif;
add_action( 'whole_content_start_action', 'whole_content_start', 10 );

if ( ! function_exists( 'whole_header_image' ) ) :
    /**
     * Header Image codes
     *
     * @since  Whole 1.0.0
     *
     */
    function whole_header_image() {
        if ( whole_is_frontpage() )
            return;
        $header_image = get_header_image();
        if ( is_singular() ) :
            $header_image = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'full' ) : $header_image;
        endif;
        $options  = whole_get_theme_options();
        ?>


        <div id="page-site-header" class="relative" style="background-image: url('<?php echo esc_url( $header_image ); ?>');">
            <div class="overlay"></div>
            <div class="wrapper">
                <header class="page-header">
                    <?php whole_custom_header_banner_title(); ?>
                </header>
                <?php whole_add_breadcrumb(); ?>
            </div>
        </div><!-- #page-site-header -->

        <?php
    }
endif;
add_action( 'whole_header_image_action', 'whole_header_image', 10 );

if ( ! function_exists( 'whole_add_breadcrumb' ) ) :
	/**
	 * Add breadcrumb.
	 *
	 * @since  Whole 1.0.0
	 */
	function whole_add_breadcrumb() {
		$options = whole_get_theme_options();

		// Bail if Breadcrumb disabled.
		$breadcrumb = $options['breadcrumb_enable'];
		if ( false === $breadcrumb ) {
			return;
		}
		
		// Bail if Home Page.
		if ( whole_is_frontpage() ) {
			return;
		}

		echo '<div id="breadcrumb-list" >';
				/**
				 * whole_simple_breadcrumb hook
				 *
				 * @hooked whole_simple_breadcrumb -  10
				 *
				 */
				do_action( 'whole_simple_breadcrumb' );
		echo '</div><!-- #breadcrumb-list -->';
	}
endif;

if ( ! function_exists( 'whole_content_end' ) ) :
	/**
	 * Site content codes
	 *
	 * @since  Whole 1.0.0
	 *
	 */
	function whole_content_end() {
		?>
        </div><!-- #content -->
		<?php
	}
endif;
add_action( 'whole_content_end_action', 'whole_content_end', 10 );

if ( ! function_exists( 'whole_footer_start' ) ) :
	/**
	 * Footer starts
	 *
	 * @since  Whole 1.0.0
	 *
	 */
	function whole_footer_start() {
		?>
		<footer id="colophon" class="site-footer" role="contentinfo">
			
		<?php
	}
endif;
add_action( 'whole_footer', 'whole_footer_start', 10 );

if ( ! function_exists( 'whole_footer_site_info' ) ) :
	/**
	 * Footer starts
	 *
	 * @since  Whole 1.0.0
	 *
	 */
	function whole_footer_site_info() {
		$options = whole_get_theme_options();

		$copyright_text = $options['copyright_text'];
		?>
		<div class="site-info">
			<div class="wrapper">				
				<div class="copy-right-text">
					<span>
					<?php 
						echo whole_santize_allow_tag( $copyright_text ); 
						if ( function_exists( 'the_privacy_policy_link' ) ) {
							the_privacy_policy_link( ' | ' );
						}
					?>
					</span>
				</div>
				
			</div><!-- .wrapper -->    
		</div><!-- .site-info -->

		<?php
	}
endif;
add_action( 'whole_footer', 'whole_footer_site_info', 40 );

if ( ! function_exists( 'whole_footer_scroll_to_top' ) ) :
	/**
	 * Footer starts
	 *
	 * @since  Whole 1.0.0
	 *
	 */
	function whole_footer_scroll_to_top() {
		$options  = whole_get_theme_options();
		if ( true === $options['scroll_top_visible'] ) : ?>
			<div class="backtotop"><?php echo whole_get_svg( array( 'icon' => 'up' ) ); ?></div>
		<?php endif;
	}
endif;
add_action( 'whole_footer', 'whole_footer_scroll_to_top', 40 );
